@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# Copyright 2005-2007 Messiah College. All rights reserved.
+# Copyright 2005-2009 Messiah College. All rights reserved.
 # Jason Long <jlong@messiah.edu>
 
 # Copyright (c) 2004 Anthony D. Urso. All rights reserved.
@@ -89,7 +89,7 @@ is written to the referenced string or file handle.
 package Mail::DKIM::Verifier;
 use base "Mail::DKIM::Common";
 use Carp;
-our $VERSION = 0.31;
+our $VERSION = 0.34;
 
 sub init
 {
@@ -500,19 +500,12 @@ and verifies the signature.
   my $policy = $dkim->fetch_author_policy;
   my $policy_result = $policy->apply($dkim);
 
-The "author" policy, as I call it, is the DKIM Sender Signing Practices
+This method retrieves the DKIM Sender Signing Practices
 record as described in Internet Draft draft-ietf-dkim-ssp-00-01dc.
-I call it the "author" policy because it is keyed to the email address
-in the From: header, i.e. the author of the message.
+This Internet Draft is now obsolete; this method is only kept for
+backward-compatibility purposes.
 
-The IETF is still actively working on this Internet Draft, so the
-exact mechanisms are subject to change.
-
-If the email being verified has no From header at all
-(which violates email standards),
-then this method will C<die>.
-
-The result of the apply() method is one of: "accept", "reject", "neutral".
+Please use the L</"policies()"> method instead.
 
 =cut
 
@@ -532,6 +525,48 @@ sub fetch_author_policy
 			);
 }
 
+=head2 fetch_author_domain_policies() - retrieves ADSP records from DNS
+
+  my @policies = $dkim->fetch_author_domain_policies;
+  foreach my $policy (@policies)
+  {
+      my $policy_result = $policy->apply($dkim);
+  }
+
+This method will retrieve all applicable
+"author-domain-signing-practices" published in DNS for this message.
+Author policies are keyed to the email address(es) in the From: header,
+i.e. the claimed author of the message.
+
+This method returns a *list* of policy records, since there is allowed
+to be zero or multiple email addresses in the From: header.
+
+The result of the apply() method is one of: "accept", "reject", "neutral".
+
+See also: L</"policies()">.
+
+=cut
+
+sub fetch_author_domain_policies
+{
+	my $self = shift;
+	use Mail::DKIM::AuthorDomainPolicy;
+
+	return () unless $self->{headers_by_name}->{from};
+	my @list = Mail::Address->parse(
+		$self->{headers_by_name}->{from}
+		);
+	my @authors = map { $_->address } @list;
+
+	# fetch the policies
+	return map {
+		Mail::DKIM::DkimPolicy->fetch(
+			Protocol => "dns",
+			Author => $_,
+			)
+		} @authors;
+}
+
 =head2 fetch_sender_policy() - retrieves a signing policy from DNS
 
   my $policy = $dkim->fetch_sender_policy;
@@ -550,19 +585,21 @@ then this method will C<die>.
 
 The result of the apply() method is one of: "accept", "reject", "neutral".
 
+See also: L</"policies()">.
+
 =cut
 
 sub fetch_sender_policy
 {
 	my $self = shift;
-	use Mail::DKIM::Policy;
+	use Mail::DKIM::DkPolicy;
 
 	# determine addresses found in the "From" and "Sender" headers
 	my $author = $self->message_originator->address;
 	my $sender = $self->message_sender->address;
 
 	# fetch the policy
-	return Mail::DKIM::Policy->fetch(
+	return Mail::DKIM::DkPolicy->fetch(
 			Protocol => "dns",
 			Author => $author,
 			Sender => $sender,
@@ -612,6 +649,44 @@ transmission of the message. For example, if a secretary were to send a
 message for another person, the "sender" would be the secretary and
 the "originator" would be the actual author.
 
+=head2 policies() - retrieves applicable signing policies from DNS
+
+  my @policies = $dkim->policies;
+  foreach my $policy (@policies)
+  {
+      $policy_result = $policy->apply($dkim);
+      # $policy_result is one of "accept", "reject", "neutral"
+  }
+
+This method searches for and returns any signing policies that would
+apply to this message. Signing policies are selected based on the
+domain that the message *claims* to be from. So, for example, if
+a message claims to be from security@bank, and forwarded by
+trusted@listserv, when in reality the message came from foe@evilcorp,
+this method would check for signing policies for security@bank and
+trusted@listserv. The signing policies might tell whether
+foe@evilcorp (the real sender) is allowed to send mail claiming
+to be from your bank or your listserv.
+
+I say "might tell", because in reality this is still really hard to
+specify with any accuracy. In addition, most senders do not publish
+useful policies.
+
+=cut
+
+sub policies
+{
+	my $self = shift;
+
+	my $sender_policy = eval { $self->fetch_sender_policy() };
+	my $author_policy = eval { $self->fetch_author_policy() };
+	return (
+		$sender_policy ? $sender_policy : (),
+		$author_policy ? $author_policy : (),
+		$self->fetch_author_domain_policies(),
+		);
+}
+
 
 =head2 result() - access the result of the verification
 
@@ -634,7 +709,15 @@ does not contain a correct value for the message.
 =item invalid
 
 Returned if a DKIM-Signature could not be checked because of a problem
-in the signature itself or the public key record.
+in the signature itself or the public key record. I.e. the signature
+could not be processed.
+
+=item temperror
+
+Returned if a DKIM-Signature could not be checked due to some error
+which is likely transient in nature, such as a temporary inability
+to retrieve a public key. A later attempt may produce a better
+result.
 
 =item none
 
@@ -644,6 +727,9 @@ Returned if no DKIM-Signature headers (valid or invalid) were found.
 
 In case of multiple signatures, the "best" result will be returned.
 Best is defined as "pass", followed by "fail", "invalid", and "none".
+To examine the results of individual signatures, use the L</signatures>
+method to retrieve the signature objects. See
+L<Mail::DKIM::Signature/result>.
 
 =cut
 
@@ -651,7 +737,7 @@ Best is defined as "pass", followed by "fail", "invalid", and "none".
 
   my $detail = $dkim->result_detail;
 
-The detail is constructed by taking the result (i.e. one of "pass", "fail",
+The detail is constructed by taking the result (e.g. "pass", "fail",
 "invalid" or "none") and appending any details provided by the verification
 process in parenthesis.
 
@@ -723,7 +809,7 @@ Jason Long, E<lt>jlong@messiah.eduE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006-2007 by Messiah College
+Copyright (C) 2006-2009 by Messiah College
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.6 or,
